@@ -37,7 +37,7 @@ class Event:
         users = list(User.objects.filter(id__in=list(set(map(lambda x:x.id, self.users.copy())))))
 
         if isinstance(users_array, list):
-            users = list(set(map(lambda x:x.id, self.users.copy())).union(map(lambda x:x.id, users_array)))
+            users = User.objects.filter(id__in=list(set(map(lambda x:x.id, self.users.copy())).union(map(lambda x:x.id, users_array))))
 
         idx = 0
         if isinstance(progress, Progress) and len:
