@@ -9,10 +9,15 @@ logger1 = logging.getLogger(__name__)
 
 
 def dictinct_list(l, _sorted=False, key=None):
+    if l is None:
+        return None
+
     ds = []
-    for item in l:
-        if not item in ds:
-            ds.append(item)
+    if isinstance(l, list):
+        ds = list(set(l.copy()))
+
+    if isinstance(l, map):
+        ds = list(set(list(l).copy()))
 
     if _sorted:
         return sorted(ds, key=lambda x: x[key])
@@ -384,6 +389,7 @@ class StackWithId(Stack):
 
         return res[0]
 
+
 def get_list_nums_key_dict(data):
     res = []
     if isinstance(data, dict):
