@@ -18,54 +18,65 @@ class UserManager(BaseUserManager):
     def getRecord(cls, **kwargs):
         record = kwargs.get('record')
         res = {
-            "id": record.id,
-            "username": record.username,
-            "description": record.description,
-            "first_name": record.first_name,
-            "last_name": record.last_name,
-            "email": record.email,
-            "middle_name": record.middle_name,
-            "short_name": record.get_short_name,
-            "short_name1": record.get_short_name1,
-            "password": record.password,
-            "last_login": record.last_login,
-            "lastmodified": record.lastmodified,
-            "editing": record.editing,
-            "deliting": record.deliting,
-            "color": record.color,
-            "bot": IsBitOn(record.props, 0),
+            'birtdate': record.birtdate,
+            'bot': IsBitOn(record.props, 0),
+            'color': record.color,
+            'deliting': record.deliting,
+            'description': record.description,
+            'editing': record.editing,
+            'email': record.email,
+            'first_name': record.first_name,
+            'id': record.id,
+            'last_login': record.last_login,
+            'last_name': record.last_name,
+            'lastmodified': record.lastmodified,
+            'middle_name': record.middle_name,
+            'password': record.password,
+            'real_name': record.real_name,
+            'short_name': record.get_short_name,
+            'short_name1': record.get_short_name1,
+            'username': record.username,
         }
         return res
 
     @classmethod
     def getRecord1(cls, record):
         res = {
-            "id": record.id,
-            "username": record.username,
-            "description": record.description,
-            "first_name": record.first_name,
-            "last_name": record.last_name,
-            "email": record.email,
-            "middle_name": record.middle_name,
-            "short_name": record.get_short_name,
-            "short_name1": record.get_short_name1,
-            "password": record.password,
-            "last_login": record.last_login,
-            "lastmodified": record.lastmodified,
-            "editing": record.editing,
-            "deliting": record.deliting,
-            "color": record.color,
-            "bot": IsBitOn(record.props, 0),
+            'birtdate': record.birtdate,
+            'bot': IsBitOn(record.props, 0),
+            'color': record.color,
+            'deliting': record.deliting,
+            'description': record.description,
+            'editing': record.editing,
+            'email': record.email,
+            'first_name': record.first_name,
+            'id': record.id,
+            'last_login': record.last_login,
+            'last_name': record.last_name,
+            'lastmodified': record.lastmodified,
+            'middle_name': record.middle_name,
+            'password': record.password,
+            'real_name': record.real_name,
+            'short_name': record.get_short_name,
+            'short_name1': record.get_short_name1,
+            'username': record.username,
+        }
+        return res
+
+    @classmethod
+    def getRecordPhoto(cls, record):
+        res = {
+            'id': record.id,
+            'src': f'logic/User/Photo/{record.id}/'
         }
         return res
 
     def updateFromRequest(self, request):
         request = DSRequest(request=request)
         data = request.get_data()
-        for k, v in data.items():
-            if k == '0':
-                data = v
-            break
+
+        data = self.check_data_for_multi_select(data=data)
+        _data = data.copy()
 
         delAttr(data, 'usergroup')
         oldValues = request.get_oldValues()
@@ -74,10 +85,7 @@ class UserManager(BaseUserManager):
         if not _oldValues:
             _oldValues = oldValues
 
-        for k, v in _oldValues.items():
-            if k == '0':
-                _oldValues = v
-            break
+        _oldValues = self.check_data_for_multi_select(data=_oldValues)
 
         data = self._remove_prop_(data)
         values = [item for item in dictinct_list(set(_oldValues) - set(data)) if not item.startswith('_')]
@@ -109,7 +117,7 @@ class UserManager(BaseUserManager):
             setAttr(data, 'password', user.password)
             setAttr(data, 'short_name', user.get_short_name)
 
-        return data
+        return _data
 
     def createFromRequest(self, request):
         request = DSRequest(request=request)
