@@ -292,9 +292,9 @@ def create_table(
         on_commit_str = ''
 
     if sql_str is None:
-        sql_txt += f'''CREATE {temporary} TABLE {table_name} ({fields_str}) {on_commit_str};'''
+        sql_txt += f'''CREATE {temporary} TABLE {table_name} ({fields_str}) {on_commit_str}'''
     else:
-        sql_txt += f'''CREATE {temporary} TABLE {table_name} as ({sql_str}); {on_commit_str};'''
+        sql_txt += f'''CREATE {temporary} TABLE {table_name} as ({sql_str}); {on_commit_str}'''
 
     sql_txt += pk_str
     sql_txt += ';\n'.join(any_constraints)
@@ -314,6 +314,98 @@ def create_table(
         raise ex
 
 
+def create_table1(
+        fields_str=None,
+        sql_str=None,
+        temporary='',
+        on_commit=None,
+        params=[],
+        indexes=[],
+        unique_indexes=[],
+        primary_key=None,
+        table_name=None,
+        any_constraints=[],
+        drop=True) -> None:
+    if table_name is None:
+        raise Exception(f'Table must have name')
+
+    key = f'create_tmp_table{table_name}'
+    settings.LOCKS.acquire(key)
+
+    pk_str = ''
+    if primary_key is not None:
+        if not isinstance(primary_key, list):
+            primary_key = [primary_key]
+
+        # pk_str = f'''ALTER TABLE {table_name}
+        #             ADD CONSTRAINT {table_name}_pk
+        #                 PRIMARY KEY ({','.join(primary_key)});'''
+
+        pk_str = f'''ALTER TABLE {table_name}
+                            ADD CONSTRAINT {table_name}_pk
+                                UNIQUE ({','.join(primary_key)});'''
+
+    indexes_str = ''
+    if isinstance(indexes, list):
+        indexes = [f'''CREATE INDEX {table_name}_{index}_idx ON {table_name} USING btree ("{index}")''' for index in indexes]
+        indexes_str = ';'.join(indexes)
+
+    unique_indexes_str = ''
+    if isinstance(unique_indexes, list):
+        if len(unique_indexes):
+            qt_fld = list(map(lambda x: f'"{x}"', unique_indexes[0:len(unique_indexes) - 1]))
+            unique_indexes_str = ';\n' + f'''CREATE UNIQUE INDEX {table_name}_{'_'.join(unique_indexes)}_idx ON {table_name} USING btree ({','.join(qt_fld)}) WHERE ("{unique_indexes[len(unique_indexes) - 1]}" is null);'''
+
+    sql_txt = ''
+    if drop:
+        sql_txt = f'''DROP TABLE IF EXISTS {table_name} CASCADE;'''
+
+    on_commit_str = f'ON COMMIT {on_commit}'
+    if on_commit is None:
+        on_commit_str = ''
+
+    if sql_str is None:
+        sql_txt += f'''CREATE {temporary} TABLE {table_name} ({fields_str}) {on_commit_str};'''
+    else:
+        sql_txt += f'''CREATE {temporary} TABLE {table_name} as ({sql_str}); {on_commit_str};'''
+
+    sql_txt += pk_str
+    sql_txt += ';\n'.join(any_constraints)
+    sql_txt += indexes_str
+    sql_txt += unique_indexes_str
+
+    try:
+
+        with connection.cursor() as cursor:
+            logger.debug(f'Creating: {table_name}')
+            cursor.execute(sql_txt, params)
+            logger.debug(f'Created: {table_name}')
+            view_name = table_name.replace("tbl", "view")
+
+            sql_txt = f'insert into {table_name} select * from {view_name} where id=%s'
+
+            sql_txt1 = f'select count(*) from planing_production_order_lt_view'
+            cursor.execute(sql_txt1, params)
+            cnt, = cursor.fetchone()
+            i = 0
+
+            sql_txt1 = f'select id from planing_production_order_lt_view'
+
+            cursor.execute(sql_txt1, params)
+            rows = cursor.fetchall()
+            for row in rows:
+                # logger.debug(f'Inserting ({i} form {cnt}): Where id={row[0]}')
+                cursor.execute(sql_txt, row)
+                i += 1
+
+        settings.LOCKS.release(key)
+    except Exception as ex:
+        exc_info = sys.exc_info()
+        logger.error(msg=ex, exc_info=exc_info)
+        settings.LOCKS.release(key)
+        raise ex
+
+
 def create_tmp_table(fields_str=None, sql_str=None, on_commit='delete rows', params=[], indexes=[], unique_indexes=[], table_name=None, drop=True) -> None:
     create_table(
         drop=drop,
