@@ -44,11 +44,14 @@ class TreeAuditModelQuerySet(AuditQuerySet):
             limit = f'limit {limit}'
         else:
             limit = ''
+
         if id is not None:
             if isinstance(id, int):
                 id = tuple([id])
             elif isinstance(id, str):
-                id = int(id)
+                id = tuple([int(id)])
+            elif isinstance(id, list):
+                id = tuple(id)
             elif not isinstance(id, tuple):
                 raise Exception(f'id must be list or int')
 
@@ -74,7 +77,7 @@ class TreeAuditModelQuerySet(AuditQuerySet):
                             select {distinct} {fields} from r {where_clause1} {order_by_clause} limit %s offset %s
                         '''
             # logger.debug(f'sql: {sql_text}')
-            res = super().raw(sql_text, params=((id,), end, start))
+            res = super().raw(sql_text, params=(id, end, start))
         else:
             child_parent_value_str = f' = {child_parent_value}'
             if where_clause0 == '':
@@ -156,7 +159,9 @@ class TreeAuditModelQuerySet(AuditQuerySet):
                               parent_id='parent_id',
                               child_parent_value=None,
                               include_self=True,
+                              where_clause0='',
                               where_clause='',
+                              where_clause1='',
                               distinct='',
                               sql_text=None,
                               fields='*',
@@ -170,6 +175,8 @@ class TreeAuditModelQuerySet(AuditQuerySet):
             child_parent_value=child_parent_value,
             include_self=include_self,
             where_clause=where_clause,
+            where_clause0=where_clause0,
+            where_clause1=where_clause1,
             distinct=distinct,
             sql_text=sql_text,
             fields=fields,
@@ -257,7 +264,9 @@ class TreeAuditModelManager(AuditManager):
                               parent_id='parent_id',
                               child_parent_value=None,
                               include_self=True,
+                              where_clause0='',
                               where_clause='',
+                              where_clause1='',
                               distinct='',
                               sql_text=None,
                               fields='*'
@@ -272,6 +281,8 @@ class TreeAuditModelManager(AuditManager):
             include_self=include_self,
             distinct=distinct,
             where_clause=where_clause,
+            where_clause0=where_clause0,
+            where_clause1=where_clause1,
             sql_text=sql_text,
             fields=fields,
             limit1=limit1
