@@ -95,13 +95,13 @@ class WebSocket:
                 raise Exception(f'message is not dict instance')
 
         try:
-            key = 'WebSocket.send_message'
-            settings.LOCKS.acquire(key)
+            # key = 'WebSocket.send_message'
+            # settings.LOCKS.acquire(key)
             url = f'ws://{host}:{port}/ws/{channel}/'
             ws = websocket.create_connection(url, class_=WebSocketExt)
             ws.send(json.dumps(message, cls=JSONEncoder))
             ws.close()
-            settings.LOCKS.release(key)
+            # settings.LOCKS.release(key)
         except Exception as ex:
 
             exc_info = sys.exc_info()
@@ -114,7 +114,6 @@ class WebSocket:
                 logger.error(x)
 
             del exc_info
-            settings.LOCKS.release(key)
 
     @classmethod
     def full_refresh_grid(cls, grid_id):
