@@ -4,6 +4,7 @@ from django.db import transaction
 
 from isc_common import delAttr, setAttr
 from isc_common.auth.models.user import User
+from isc_common.common import closed
 from isc_common.fields.code_field import CodeField
 from isc_common.fields.related import ForeignKeyCascade
 from isc_common.http.DSRequest import DSRequest
@@ -77,6 +78,37 @@ class Messages_theme_Manager(CommonTreeGridManager):
             res = super().filter(id=data.get('id')).update(**data)
         return res
 
+    def deleteFromRequest(self, request, removed=None, ):
+        from tracker.models.messages import Messages
+        request = DSRequest(request=request)
+        res = 0
+        tuple_ids = request.get_olds_tuple_ids()
+        ids = list(map(lambda x: x[0], tuple_ids))
+
+        top_messages = list(map(lambda x: x.id, Messages.objects.filter(theme_id__in=ids)))
+        messages = list(Messages.objects1.get_descendants(id=top_messages, child_id='id'))
+        ids = list(map(lambda x: x.id, messages))
+
+        top_messages = list(map(lambda x: x.id, Messages.objects.filter(id__in=ids, state__code=closed)))
+        if len(top_messages) > 0:
+            raise Exception('В выбранном диапазоне присутствуют закрытые позиции.')
+
+        top_messages = list(map(lambda x: x.id, Messages.objects.filter(id__in=ids).exclude(user=request.user)))
+        if len(top_messages) > 0:
+            raise Exception('В выбранном диапазоне присутствуют позиции cсозданные другими пользователями.')
+
+        with transaction.atomic():
+            for id, mode in tuple_ids:
+                if mode == 'hide':
+                    super().filter(id=id).soft_delete()
+                    res += 1
+                elif mode == 'visible':
+                    super().filter(id=id).soft_restore()
+                else:
+                    qty, _ = super().filter(id=id).delete()
+                    res += qty
+        return res
+
 
 class Messages_theme(BaseRefHierarcy):
     code = CodeField(unique=True)
